;;; solarized-palettes.el

;; see solarized.el for general package header information

;;; Commentary:

;; This file only contains data which is lists of colors of some sort, there is
;; also code that generates palettes in solarized.el. That code does not belong
;; here.

;;; Code:

(defvar solarized-dark-color-palette-alist
  '(;; solarized-dark palette
    (base03      . "#002b36")
    (base02      . "#073642")
    (base01      . "#586e75")
    (base00      . "#657b83")
    (base0       . "#839496")
    (base1       . "#93a1a1")
    (base2       . "#eee8d5")
    (base3       . "#fdf6e3")
    (yellow      . "#b58900")
    (orange      . "#cb4b16")
    (red         . "#dc322f")
    (magenta     . "#d33682")
    (violet      . "#6c71c4")
    (blue        . "#268bd2")
    (cyan        . "#2aa198")
    (green       . "#859900")
    (yellow-1bg  . "#273632")
    (yellow-1fg  . "#cca551")
    (yellow-2bg  . "#4a4527")
    (yellow-2fg  . "#cfad68")
    (yellow-d    . "#7B6000")
    (yellow-l    . "#DEB542")
    (orange-1bg  . "#2d3031")
    (orange-1fg  . "#df7d50")
    (orange-2bg  . "#553325")
    (orange-2fg  . "#df8f66")
    (orange-d    . "#8B2C02")
    (orange-l    . "#F2804F")
    (red-1bg     . "#302f33")
    (red-1fg     . "#ec745f")
    (red-2bg     . "#5b2e2c")
    (red-2fg     . "#e98871")
    (red-d       . "#990A1B")
    (red-l       . "#FF6E64")
    (magenta-1bg . "#2a2f3e")
    (magenta-1fg . "#e1769b")
    (magenta-2bg . "#543049")
    (magenta-2fg . "#e08aa2")
    (magenta-d   . "#93115C")
    (magenta-l   . "#F771AC")
    (violet-1bg  . "#0f3347")
    (violet-1fg  . "#9994cb")
    (violet-2bg  . "#233d61")
    (violet-2fg  . "#a6a0c8")
    (violet-d    . "#3F4D91")
    (violet-l    . "#9EA0E5")
    (blue-1bg    . "#003649")
    (blue-1fg    . "#7ca7d5")
    (blue-2bg    . "#004666")
    (blue-2fg    . "#92aecf")
    (blue-d      . "#00629D")
    (blue-l      . "#69B7F0")
    (cyan-1bg    . "#013941")
    (cyan-1fg    . "#76b8ab")
    (cyan-2bg    . "#004e52")
    (cyan-2fg    . "#8cbcae")
    (cyan-d      . "#00736F")
    (cyan-l      . "#69CABF")
    (green-1bg   . "#1d3732")
    (green-1fg   . "#a8b152")
    (green-2bg   . "#374a27")
    (green-2fg   . "#b2b769")
    (green-d     . "#546E00")
    (green-l     . "#B4C342")
    ;; palette end
    )
  "The solarized color palette alist.")

(defvar solarized-light-color-palette-alist
  '(;; solarized-light palette
    (base03      . "#002b36")
    (base02      . "#073642")
    (base01      . "#586e75")
    (base00      . "#657b83")
    (base0       . "#839496")
    (base1       . "#93a1a1")
    (base2       . "#eee8d5")
    (base3       . "#fdf6e3")
    (yellow      . "#b58900")
    (orange      . "#cb4b16")
    (red         . "#dc322f")
    (magenta     . "#d33682")
    (violet      . "#6c71c4")
    (blue        . "#268bd2")
    (cyan        . "#2aa198")
    (green       . "#859900")
    (yellow-1bg  . "#f8e8c6")
    (yellow-1fg  . "#876d26")
    (yellow-2bg  . "#f1d49b")
    (yellow-2fg  . "#766634")
    (yellow-d    . "#7B6000")
    (yellow-l    . "#DEB542")
    (orange-1bg  . "#fedfc5")
    (orange-1fg  . "#974727")
    (orange-2bg  . "#ffbd99")
    (orange-2fg  . "#854a33")
    (orange-d    . "#8B2C02")
    (orange-l    . "#F2804F")
    (red-1bg     . "#ffdec8")
    (red-1fg     . "#a33c35")
    (red-2bg     . "#ffb9a1")
    (red-2fg     . "#8e433d")
    (red-d       . "#990A1B")
    (red-l       . "#FF6E64")
    (magenta-1bg . "#fdded7")
    (magenta-1fg . "#9a3f6c")
    (magenta-2bg . "#fdbac6")
    (magenta-2fg . "#854568")
    (magenta-d   . "#93115C")
    (magenta-l   . "#F771AC")
    (violet-1bg  . "#ebe4e2")
    (violet-1fg  . "#4f5e99")
    (violet-2bg  . "#d1c9e3")
    (violet-2fg  . "#475a8b")
    (violet-d    . "#3F4D91")
    (violet-l    . "#9EA0E5")
    (blue-1bg    . "#e7e8e4")
    (blue-1fg    . "#1e6fa2")
    (blue-2bg    . "#c3d5e9")
    (blue-2fg    . "#246792")
    (blue-d      . "#00629D")
    (blue-l      . "#69B7F0")
    (cyan-1bg    . "#e4ecda")
    (cyan-1fg    . "#207e7b")
    (cyan-2bg    . "#bedfcf")
    (cyan-2fg    . "#247374")
    (cyan-d      . "#00736F")
    (cyan-l      . "#69CABF")
    (green-1bg   . "#efeac7")
    (green-1fg   . "#657827")
    (green-2bg   . "#dbdb9c")
    (green-2fg   . "#5b6e35")
    (green-d     . "#546E00")
    (green-l     . "#B4C342")
    ;; palette end
    )
  "The solarized color palette alist.")

(defvar solarized-dark-high-contrast-palette-alist
  '(;; solarized-dark-high-contrast palette
    (base03      . "#002732")
    (base02      . "#01323d")
    (base01      . "#62787f")
    (base00      . "#60767e")
    (base0       . "#8d9fa1")
    (base1       . "#9eacac")
    (base2       . "#faf3e0")
    (base3       . "#ffffee")
    (yellow      . "#c49619")
    (orange      . "#db5823")
    (red         . "#ec423a")
    (magenta     . "#e2468f")
    (violet      . "#7a7ed2")
    (blue        . "#3c98e0")
    (cyan        . "#3cafa5")
    (green       . "#93a61a")
    (yellow-1bg  . "#273430")
    (yellow-1fg  . "#d7b15d")
    (yellow-2bg  . "#4d4729")
    (yellow-2fg  . "#d8b974")
    (yellow-d    . "#7B6000")
    (yellow-l    . "#DEB542")
    (orange-1bg  . "#2d2e2f")
    (orange-1fg  . "#eb895c")
    (orange-2bg  . "#583427")
    (orange-2fg  . "#e99a72")
    (orange-d    . "#8B2C02")
    (orange-l    . "#F2804F")
    (red-1bg     . "#2f2d32")
    (red-1fg     . "#f8806a")
    (red-2bg     . "#5e302e")
    (red-2fg     . "#f4937c")
    (red-d       . "#990A1B")
    (red-l       . "#FF6E64")
    (magenta-1bg . "#2a2d3d")
    (magenta-1fg . "#ed82a8")
    (magenta-2bg . "#57324c")
    (magenta-2fg . "#e995ae")
    (magenta-d   . "#93115C")
    (magenta-l   . "#F771AC")
    (violet-1bg  . "#113145")
    (violet-1fg  . "#a2a0d8")
    (violet-2bg  . "#273f63")
    (violet-2fg  . "#aeabd4")
    (violet-d    . "#3F4D91")
    (violet-l    . "#9EA0E5")
    (blue-1bg    . "#023447")
    (blue-1fg    . "#85b3e2")
    (blue-2bg    . "#014868")
    (blue-2fg    . "#99badc")
    (blue-d      . "#00629D")
    (blue-l      . "#69B7F0")
    (cyan-1bg    . "#03373f")
    (cyan-1fg    . "#7fc4b8")
    (cyan-2bg    . "#055054")
    (cyan-2fg    . "#93c8ba")
    (cyan-d      . "#00736F")
    (cyan-l      . "#69CABF")
    (green-1bg   . "#1e3531")
    (green-1fg   . "#b3bd5f")
    (green-2bg   . "#3a4c29")
    (green-2fg   . "#bbc275")
    (green-d     . "#546E00")
    (green-l     . "#B4C342")
    ;; palette end
    )
  "The solarized color palette alist.")

(defvar solarized-light-high-contrast-palette-alist
  '(;; solarized-light-high-contrast palette
    (base03      . "#00212b")
    (base02      . "#002b37")
    (base01      . "#5d737a")
    (base00      . "#596e76")
    (base0       . "#88999b")
    (base1       . "#98a6a6")
    (base2       . "#f4eedb")
    (base3       . "#fffce9")
    (yellow      . "#a67c00")
    (orange      . "#bb3e06")
    (red         . "#cc1f24")
    (magenta     . "#c42475")
    (violet      . "#5e65b6")
    (blue        . "#007ec4")
    (cyan        . "#11948b")
    (green       . "#778c00")
    (yellow-1bg  . "#f7ebcb")
    (yellow-1fg  . "#7a6120")
    (yellow-2bg  . "#ecd29c")
    (yellow-2fg  . "#6b5a2c")
    (yellow-d    . "#7B6000")
    (yellow-l    . "#DEB542")
    (orange-1bg  . "#fee2c8")
    (orange-1fg  . "#8a3b1c")
    (orange-2bg  . "#fabc97")
    (orange-2fg  . "#793e28")
    (orange-d    . "#8B2C02")
    (orange-l    . "#F2804F")
    (red-1bg     . "#ffe1cb")
    (red-1fg     . "#952f2a")
    (red-2bg     . "#ffb79f")
    (red-2fg     . "#823731")
    (red-d       . "#990A1B")
    (red-l       . "#FF6E64")
    (magenta-1bg . "#fce1da")
    (magenta-1fg . "#8e3160")
    (magenta-2bg . "#f9b9c4")
    (magenta-2fg . "#7a395c")
    (magenta-d   . "#93115C")
    (magenta-l   . "#F771AC")
    (violet-1bg  . "#ebe7e5")
    (violet-1fg  . "#44528c")
    (violet-2bg  . "#cdc8e1")
    (violet-2fg  . "#3d4f7e")
    (violet-d    . "#3F4D91")
    (violet-l    . "#9EA0E5")
    (blue-1bg    . "#e6ebe7")
    (blue-1fg    . "#0a6395")
    (blue-2bg    . "#bfd2e6")
    (blue-2fg    . "#185b85")
    (blue-d      . "#00629D")
    (blue-l      . "#69B7F0")
    (cyan-1bg    . "#e4efdd")
    (cyan-1fg    . "#10716f")
    (cyan-2bg    . "#b9ddcd")
    (cyan-2fg    . "#196767")
    (cyan-d      . "#00736F")
    (cyan-l      . "#69CABF")
    (green-1bg   . "#eeedcb")
    (green-1fg   . "#596c21")
    (green-2bg   . "#d5d99d")
    (green-2fg   . "#51622d")
    (green-d     . "#546E00")
    (green-l     . "#B4C342")
    ;; palette end
    )
  "The solarized color palette alist.")

;;; gruvbox themes

(defvar solarized-gruvbox-colors
  '(;; gruvbox colors
    (dark0_hard    . "#1d2021")
    (dark0         . "#282828")
    (dark0_soft    . "#32302f")
    (dark1         . "#3c3836")
    (dark2         . "#504945")
    (dark3         . "#665c54")
    (dark4         . "#7c6f64")
    (gray          . "#928374")
    (light0_hard   . "#f9f5d7")
    (light0        . "#fbf1c7")
    (light0_soft   . "#f2e5bc")
    (light1        . "#ebdbb2")
    (light2        . "#d5c4a1")
    (light3        . "#bdae93")
    (light4        . "#a89984")
    (red           . "#cc241d")
    (green         . "#98971a")
    (yellow        . "#d79921")
    (blue          . "#458588")
    (purple        . "#b16286")
    (aqua          . "#689d6a")
    (orange        . "#d65d0e")
    (bright_red    . "#fb4933")
    (bright_green  . "#b8bb26")
    (bright_yellow . "#fabd2f")
    (bright_blue   . "#83a598")
    (bright_purple . "#d3869b")
    (bright_aqua   . "#8ec07c")
    (bright_orange . "#fe8019")
    (dark_red      . "#9d0006")
    (dark_green    . "#79740e")
    (dark_yellow   . "#b57614")
    (dark_blue     . "#076678")
    (dark_purple   . "#8f3f71")
    (dark_aqua     . "#427b58")
    (dark_orange   . "#af3a03")
    ;; colors end
    )
  "The gruvbox color palette.")

(defvar solarized-gruvbox-dark-color-palette-alist
  '(;; gruvbox-dark palette
    (base03      . "#282828")
    (base02      . "#32302f")
    (base01      . "#7c6f64")
    (base00      . "#282828")
    (base0       . "#a89984")
    (base1       . "#bdae93")
    (base2       . "#a89984")
    (base3       . "#fbf1c7")
    (yellow      . "#d79921")
    (orange      . "#d65d0e")
    (red         . "#fb4933")
    (magenta     . "#d3869b")
    (violet      . "#b16286")
    (blue        . "#458588")
    (cyan        . "#689d6a")
    (green       . "#98971a")
    (yellow-1bg  . "#3f3528")
    (yellow-1fg  . "#e2b055")
    (yellow-2bg  . "#614923")
    (yellow-2fg  . "#dfb566")
    (yellow-d    . "#7B6000")
    (yellow-l    . "#DEB542")
    (orange-1bg  . "#402e25")
    (orange-1fg  . "#e48847")
    (orange-2bg  . "#62351c")
    (orange-2fg  . "#e2965a")
    (orange-d    . "#8B2C02")
    (orange-l    . "#F2804F")
    (red-1bg     . "#452e28")
    (red-1fg     . "#ff815b")
    (red-2bg     . "#6f3125")
    (red-2fg     . "#f89169")
    (red-d       . "#990A1B")
    (red-l       . "#FF6E64")
    (magenta-1bg . "#3d3335")
    (magenta-1fg . "#dda3a6")
    (magenta-2bg . "#5e434a")
    (magenta-2fg . "#dbaba4")
    (magenta-d   . "#93115C")
    (magenta-l   . "#F771AC")
    (violet-1bg  . "#392f33")
    (violet-1fg  . "#c68a97")
    (violet-2bg  . "#523642")
    (violet-2fg  . "#c89798")
    (violet-d    . "#3F4D91")
    (violet-l    . "#9EA0E5")
    (blue-1bg    . "#2c3333")
    (blue-1fg    . "#7da298")
    (blue-2bg    . "#2d4243")
    (blue-2fg    . "#90aa99")
    (blue-d      . "#00629D")
    (blue-l      . "#69B7F0")
    (cyan-1bg    . "#2f362f")
    (cyan-1fg    . "#91b382")
    (cyan-2bg    . "#384a38")
    (cyan-2fg    . "#9fb888")
    (cyan-d      . "#00736F")
    (cyan-l      . "#69CABF")
    (green-1bg   . "#363527")
    (green-1fg   . "#b4ae51")
    (green-2bg   . "#4a4821")
    (green-2fg   . "#bab462")
    (green-d     . "#546E00")
    (green-l     . "#B4C342")
    ;; palette end
    )
  "The solarized gruvbox dark palette color alist.")

(defvar solarized-gruvbox-light-color-palette-alist
  '(;; gruvbox-light palette
    (base03      . "#282828")
    (base02      . "#32302f")
    (base01      . "#665c54")
    (base00      . "#7c6f64")
    (base0       . "#3c3836")
    (base1       . "#a89984")
    (base2       . "#ebdbb2")
    (base3       . "#fbf1c7")
    (yellow      . "#b57614")
    (orange      . "#af3a03")
    (red         . "#9d0006")
    (magenta     . "#d3869b")
    (violet      . "#8f3f71")
    (blue        . "#076678")
    (cyan        . "#689d6a")
    (green       . "#98971a")
    (yellow-1bg  . "#f6e1af")
    (yellow-1fg  . "#8c6023")
    (yellow-2bg  . "#efc98b")
    (yellow-2fg  . "#7f5b2d")
    (yellow-d    . "#7B6000")
    (yellow-l    . "#DEB542")
    (orange-1bg  . "#f7d8ab")
    (orange-1fg  . "#893a18")
    (orange-2bg  . "#f0b382")
    (orange-2fg  . "#7e3e23")
    (orange-d    . "#8B2C02")
    (orange-l    . "#F2804F")
    (red-1bg     . "#f5d4aa")
    (red-1fg     . "#7e2115")
    (red-2bg     . "#eaa67f")
    (red-2fg     . "#752d21")
    (red-d       . "#990A1B")
    (red-l       . "#FF6E64")
    (magenta-1bg . "#f9e4c3")
    (magenta-1fg . "#9e6b78")
    (magenta-2bg . "#f8d1c0")
    (magenta-2fg . "#8c646e")
    (magenta-d   . "#93115C")
    (magenta-l   . "#F771AC")
    (violet-1bg  . "#eed8bd")
    (violet-1fg  . "#713c5c")
    (violet-2bg  . "#dcb3af")
    (violet-2fg  . "#694058")
    (violet-d    . "#3F4D91")
    (violet-l    . "#9EA0E5")
    (blue-1bg    . "#dedebe")
    (blue-1fg    . "#245561")
    (blue-2bg    . "#b1c2b2")
    (blue-2fg    . "#30535c")
    (blue-d      . "#00629D")
    (blue-l      . "#69B7F0")
    (cyan-1bg    . "#e7e7bb")
    (cyan-1fg    . "#577a58")
    (cyan-2bg    . "#cbdaab")
    (cyan-2fg    . "#556f55")
    (cyan-d      . "#00736F")
    (cyan-l      . "#69CABF")
    (green-1bg   . "#f0e6b1")
    (green-1fg   . "#787628")
    (green-2bg   . "#e0d78f")
    (green-2fg   . "#6f6c32")
    (green-d     . "#546E00")
    (green-l     . "#B4C342")
    ;; palette end
    )
  "The solarized gruvbox light color palette alist.")

(provide 'solarized-palettes)
;; End:

;;; solarized-palettes.el ends here
